/**
 * Copyright (c) 2013-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.launcher.exception;


/**
 * The data root path is not a valid directory
 * 
 * @author Christophe DENEUX - Linagora
 * 
 */
public class InvalidDataRootPathException extends PetalsLauncherException {

    private static final long serialVersionUID = -6672498700835868126L;

    private static final String MESSAGE_TEMPLATE = "The data root path '%s' is not a valid directory.";

    /**
     * The data root path that is invalid or unexisting.
     */
    private final String dataRootPath;

    public InvalidDataRootPathException(final String dataRootPath) {
        this(dataRootPath, null);
    }

    public InvalidDataRootPathException(final String dataRootPath, final Throwable cause) {
        super(String.format(MESSAGE_TEMPLATE, dataRootPath), cause);
        this.dataRootPath = dataRootPath;
    }

    /**
     * @return The data root path that is invalid or unexisting.
     */
    public String getDataRootPath() {
        return this.dataRootPath;
    }
}
